[SCM] WebKit Debian packaging branch, debian/unstable, updated. debian/1.1.15-1-40151-g37bb677

darin darin at 268f45cc-cd09-0410-ab3c-d52691b4dbfc
Sat Sep 26 06:56:49 UTC 2009


The following commit has been merged in the debian/unstable branch:
commit 2ce2906674ca7e90992b3fbb1e0d63c3cda5a0ad
Author: darin <darin at 268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Sun Nov 3 20:41:15 2002 +0000

    WebCore:
    
    	- fixed 3091300 -- "prelighting" on local page is still slow, despite recent bug fix
    
    	Turns out all updating would be slow if any resources on the page failed to load.
    
            * kwq/WebCoreResourceLoader.h: Add reportError, distinct from
    	cancel and finish.
            * kwq/KWQResourceLoader.mm: (-[KWQResourceLoader reportError]):
    	Set the error boolean on the job and then call through to [finish].
    
    WebKit:
    
    	- fixed 3091300 -- "prelighting" on local page is still slow, despite recent bug fix
    
    	Turns out all updating would be slow if any resources on the page failed to load.
    
            * WebCoreSupport.subproj/WebSubresourceClient.m:
            (+[WebSubresourceClient startLoadingResource:withURL:referrer:forDataSource:]):
    	Call the new reportError instead of cancel.
            (-[WebSubresourceClient handle:didFailLoadingWithError:]): Ditto.
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@2543 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebCore/ChangeLog-2002-12-03 b/WebCore/ChangeLog-2002-12-03
index d988531..419b018 100644
--- a/WebCore/ChangeLog-2002-12-03
+++ b/WebCore/ChangeLog-2002-12-03
@@ -1,5 +1,16 @@
 2002-11-03  Darin Adler  <darin at apple.com>
 
+	- fixed 3091300 -- "prelighting" on local page is still slow, despite recent bug fix
+
+	Turns out all updating would be slow if any resources on the page failed to load.
+
+        * kwq/WebCoreResourceLoader.h: Add reportError, distinct from
+	cancel and finish.
+        * kwq/KWQResourceLoader.mm: (-[KWQResourceLoader reportError]):
+	Set the error boolean on the job and then call through to [finish].
+
+2002-11-03  Darin Adler  <darin at apple.com>
+
 	- fixed 3091275 -- can't type into Answer field in RealOne Player order form
 
         * khtml/rendering/render_form.cpp:
diff --git a/WebCore/ChangeLog-2003-10-25 b/WebCore/ChangeLog-2003-10-25
index d988531..419b018 100644
--- a/WebCore/ChangeLog-2003-10-25
+++ b/WebCore/ChangeLog-2003-10-25
@@ -1,5 +1,16 @@
 2002-11-03  Darin Adler  <darin at apple.com>
 
+	- fixed 3091300 -- "prelighting" on local page is still slow, despite recent bug fix
+
+	Turns out all updating would be slow if any resources on the page failed to load.
+
+        * kwq/WebCoreResourceLoader.h: Add reportError, distinct from
+	cancel and finish.
+        * kwq/KWQResourceLoader.mm: (-[KWQResourceLoader reportError]):
+	Set the error boolean on the job and then call through to [finish].
+
+2002-11-03  Darin Adler  <darin at apple.com>
+
 	- fixed 3091275 -- can't type into Answer field in RealOne Player order form
 
         * khtml/rendering/render_form.cpp:
diff --git a/WebCore/ChangeLog-2005-08-23 b/WebCore/ChangeLog-2005-08-23
index d988531..419b018 100644
--- a/WebCore/ChangeLog-2005-08-23
+++ b/WebCore/ChangeLog-2005-08-23
@@ -1,5 +1,16 @@
 2002-11-03  Darin Adler  <darin at apple.com>
 
+	- fixed 3091300 -- "prelighting" on local page is still slow, despite recent bug fix
+
+	Turns out all updating would be slow if any resources on the page failed to load.
+
+        * kwq/WebCoreResourceLoader.h: Add reportError, distinct from
+	cancel and finish.
+        * kwq/KWQResourceLoader.mm: (-[KWQResourceLoader reportError]):
+	Set the error boolean on the job and then call through to [finish].
+
+2002-11-03  Darin Adler  <darin at apple.com>
+
 	- fixed 3091275 -- can't type into Answer field in RealOne Player order form
 
         * khtml/rendering/render_form.cpp:
diff --git a/WebCore/kwq/KWQResourceLoader.mm b/WebCore/kwq/KWQResourceLoader.mm
index d0ec3e9..8bd1a8e 100644
--- a/WebCore/kwq/KWQResourceLoader.mm
+++ b/WebCore/kwq/KWQResourceLoader.mm
@@ -92,6 +92,12 @@ using KIO::TransferJob;
     [handle release];
 }
 
+- (void)reportError
+{
+    _job->setError(1);
+    [self finish];
+}
+
 - (void)finish
 {
     ASSERT(_job);
diff --git a/WebKit/ChangeLog b/WebKit/ChangeLog
index 3793a59..4caef7a 100644
--- a/WebKit/ChangeLog
+++ b/WebKit/ChangeLog
@@ -1,3 +1,14 @@
+2002-11-03  Darin Adler  <darin at apple.com>
+
+	- fixed 3091300 -- "prelighting" on local page is still slow, despite recent bug fix
+
+	Turns out all updating would be slow if any resources on the page failed to load.
+
+        * WebCoreSupport.subproj/WebSubresourceClient.m:
+        (+[WebSubresourceClient startLoadingResource:withURL:referrer:forDataSource:]):
+	Call the new reportError instead of cancel.
+        (-[WebSubresourceClient handle:didFailLoadingWithError:]): Ditto.
+
 2002-11-02  Darin Adler  <darin at apple.com>
 
         * Panels.subproj/WebAuthenticationPanel.m: (-[WebAuthenticationPanel setUpForRequest:]):
diff --git a/WebKit/ChangeLog-2002-12-03 b/WebKit/ChangeLog-2002-12-03
index 3793a59..4caef7a 100644
--- a/WebKit/ChangeLog-2002-12-03
+++ b/WebKit/ChangeLog-2002-12-03
@@ -1,3 +1,14 @@
+2002-11-03  Darin Adler  <darin at apple.com>
+
+	- fixed 3091300 -- "prelighting" on local page is still slow, despite recent bug fix
+
+	Turns out all updating would be slow if any resources on the page failed to load.
+
+        * WebCoreSupport.subproj/WebSubresourceClient.m:
+        (+[WebSubresourceClient startLoadingResource:withURL:referrer:forDataSource:]):
+	Call the new reportError instead of cancel.
+        (-[WebSubresourceClient handle:didFailLoadingWithError:]): Ditto.
+
 2002-11-02  Darin Adler  <darin at apple.com>
 
         * Panels.subproj/WebAuthenticationPanel.m: (-[WebAuthenticationPanel setUpForRequest:]):
diff --git a/WebKit/WebCoreSupport.subproj/WebSubresourceClient.m b/WebKit/WebCoreSupport.subproj/WebSubresourceClient.m
index 484e38f..fa99bc6 100644
--- a/WebKit/WebCoreSupport.subproj/WebSubresourceClient.m
+++ b/WebKit/WebCoreSupport.subproj/WebSubresourceClient.m
@@ -3,12 +3,13 @@
     Copyright (c) 2002, Apple Computer, Inc. All rights reserved.
 */
 
+#import <WebKit/WebSubresourceClient.h>
+
 #import <WebKit/WebBridge.h>
 #import <WebKit/WebControllerPrivate.h>
 #import <WebKit/WebDataSourcePrivate.h>
 #import <WebKit/WebFrame.h>
 #import <WebKit/WebResourceLoadDelegate.h>
-#import <WebKit/WebSubresourceClient.h>
 
 #import <WebFoundation/WebAssertions.h>
 #import <WebFoundation/WebError.h>
@@ -19,7 +20,6 @@
 
 #import <WebCore/WebCoreResourceLoader.h>
 
-
 @implementation WebSubresourceClient
 
 - initWithLoader:(id <WebCoreResourceLoader>)l dataSource:(WebDataSource *)s
@@ -52,7 +52,7 @@
     
     if (![WebResourceHandle canInitWithRequest:newRequest]) {
         [newRequest release];
-        [rLoader cancel];
+        [rLoader reportError];
 
         WebError *badURLError = [[WebError alloc] initWithErrorCode:WebErrorCodeBadURLError
                                                            inDomain:WebErrorDomainWebFoundation
@@ -136,7 +136,7 @@
     // Calling _removeSubresourceClient will likely result in a call to release, so we must retain.
     [self retain];
     
-    [loader cancel];
+    [loader reportError];
     
     [dataSource _removeSubresourceClient:self];
     
diff --git a/WebKit/WebCoreSupport.subproj/WebSubresourceLoader.m b/WebKit/WebCoreSupport.subproj/WebSubresourceLoader.m
index 484e38f..fa99bc6 100644
--- a/WebKit/WebCoreSupport.subproj/WebSubresourceLoader.m
+++ b/WebKit/WebCoreSupport.subproj/WebSubresourceLoader.m
@@ -3,12 +3,13 @@
     Copyright (c) 2002, Apple Computer, Inc. All rights reserved.
 */
 
+#import <WebKit/WebSubresourceClient.h>
+
 #import <WebKit/WebBridge.h>
 #import <WebKit/WebControllerPrivate.h>
 #import <WebKit/WebDataSourcePrivate.h>
 #import <WebKit/WebFrame.h>
 #import <WebKit/WebResourceLoadDelegate.h>
-#import <WebKit/WebSubresourceClient.h>
 
 #import <WebFoundation/WebAssertions.h>
 #import <WebFoundation/WebError.h>
@@ -19,7 +20,6 @@
 
 #import <WebCore/WebCoreResourceLoader.h>
 
-
 @implementation WebSubresourceClient
 
 - initWithLoader:(id <WebCoreResourceLoader>)l dataSource:(WebDataSource *)s
@@ -52,7 +52,7 @@
     
     if (![WebResourceHandle canInitWithRequest:newRequest]) {
         [newRequest release];
-        [rLoader cancel];
+        [rLoader reportError];
 
         WebError *badURLError = [[WebError alloc] initWithErrorCode:WebErrorCodeBadURLError
                                                            inDomain:WebErrorDomainWebFoundation
@@ -136,7 +136,7 @@
     // Calling _removeSubresourceClient will likely result in a call to release, so we must retain.
     [self retain];
     
-    [loader cancel];
+    [loader reportError];
     
     [dataSource _removeSubresourceClient:self];
     

diff --git a/WebCore/kwq/WebCoreResourceLoader.h b/WebCore/kwq/WebCoreResourceLoader.h
index 21f2c5a..0d3388f 100644
--- a/WebCore/kwq/WebCoreResourceLoader.h
+++ b/WebCore/kwq/WebCoreResourceLoader.h
@@ -31,9 +31,11 @@
 
 - (void)addData:(NSData *)data;
 
-// Either cancel or finish will be called before the loader is released, but never both.
-- (void)cancel;
+// Either finish, reportError, or cancel must be called before the
+// loader is released, but never more than one.
 - (void)finish;
+- (void)reportError;
+- (void)cancel;
 
 @end
 
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list